@@ -31,14 +31,29 @@ class AlarmProcessor(BaseProcessor):
     def __init__(
             self, alarm_ttl, mysql_host, mysql_user,
             mysql_passwd, dbname, mysql_ssl=None):
+
+        self._mysql_host = mysql_host
+        self._mysql_user = mysql_user
+        self._mysql_passwd = mysql_passwd
+        self._mysql_dbname = dbname
+        self._mysql_ssl = mysql_ssl
+
         self._alarm_ttl = alarm_ttl
         self._statsd = monascastatsd.Client(name='monasca',
                                             dimensions=BaseProcessor.dimensions)
+
+        self._mysql = None
+        self._connect_to_mysql()
+
+    def _connect_to_mysql(self):
         try:
-            self._mysql = MySQLdb.connect(host=mysql_host, user=mysql_user,
-                                          passwd=unicode(mysql_passwd).encode('utf-8'),
-                                          db=dbname, ssl=mysql_ssl,
-                                          use_unicode=True, charset="utf8")
+            self._mysql = MySQLdb.connect(host=self._mysql_host,
+                                          user=self._mysql_user,
+                                          passwd=unicode(self._mysql_passwd).encode('utf-8'),
+                                          db=self._mysql_dbname,
+                                          ssl=self._mysql_ssl,
+                                          use_unicode=True,
+                                          charset="utf8")
             self._mysql.autocommit(True)
         except:
             log.exception('MySQL connect failed')
@@ -85,15 +100,31 @@ class AlarmProcessor(BaseProcessor):
 
         return True
 
+    def _build_notification(self, partition, offset, alarm):
+        cur = self._mysql.cursor()
+        db_time = self._statsd.get_timer()
+
+        with db_time.time('config_db_time'):
+            cur.execute("""SELECT name, type, address
+                           FROM alarm_action as aa
+                           JOIN notification_method as nm ON aa.action_id = nm.id
+                           WHERE aa.alarm_definition_id = %s and aa.alarm_state = %s""",
+                        [alarm['alarmDefinitionId'], alarm['newState']])
+
+        return [Notification(row[1].lower(),
+                             partition,
+                             offset,
+                             row[0],
+                             row[2],
+                             0,
+                             alarm) for row in cur]
+
     def to_notification(self, raw_alarm):
         """Check the notification setting for this project in mysql then create the appropriate notification
         """
         failed_parse_count = self._statsd.get_counter(name='alarms_failed_parse_count')
         no_notification_count = self._statsd.get_counter(name='alarms_no_notification_count')
         notification_count = self._statsd.get_counter(name='created_count')
-        db_time = self._statsd.get_timer()
-
-        cur = self._mysql.cursor()
 
         partition = raw_alarm[0]
         offset = raw_alarm[1].offset
@@ -112,23 +143,11 @@ class AlarmProcessor(BaseProcessor):
             return [], partition, offset
 
         try:
-            with db_time.time('config_db_time'):
-                cur.execute("""SELECT name, type, address
-                               FROM alarm_action as aa
-                               JOIN notification_method as nm ON aa.action_id = nm.id
-                               WHERE aa.alarm_definition_id = %s and aa.alarm_state = %s""",
-                            [alarm['alarmDefinitionId'], alarm['newState']])
+            notifications = self._build_notification(partition, offset, alarm)
         except MySQLdb.Error:
-            log.exception('Mysql Error')
-            raise
-
-        notifications = [Notification(row[1].lower(),
-                                      partition,
-                                      offset,
-                                      row[0],
-                                      row[2],
-                                      0,
-                                      alarm) for row in cur]
+            log.debug('MySQL Error.  Attempting reconnect')
+            self._connect_to_mysql()
+            notifications = self._build_notification(partition, offset, alarm)
 
         if len(notifications) == 0:
             no_notification_count += 1
